# Roadmap

Priorities, as of June 2024, are:

- add support for PyArrow
- works towards supporting projects which have shown interest in Narwhals: Altair, scikit-learn, shiny.
- make sure Narwhals' API coverage is enough to able to compute all (or at least, most of) the TPC-H
  queries
